# lgm

Lightweight python3 library for natural LanGuage Modeling (LGM). Currently, mostly useful for DL/RL experiments with natural language data.

Largely based (for now) on the fastai course v3, dl2 (March-April 2019). See here for the original notebooks, which focus mostly on vision applications: https://github.com/fastai/course-v3/tree/master/nbs/dl2.

If you are primarily a _user_ of DL models for natural language, you'll most probably want to use the fastai library instead. I built this experimental library because I needed to understand all the code thoroughly to be able to tinker with it, build new models, interface with new (types of) datasets, with various kinds of cognitive models for natural language etc.

To install:

pip3 install lgm
